#   -*- perl -*-

use Test::More tests => 5;
use Fcntl qw(S_IFCHR S_IFIFO S_IFBLK);
use strict;
use warnings;

use_ok("Sys::Mknod");

# on my system, the macro for makedev was broken.
eval { Sys::Mknod::make_dev(1,2) };
is ($@, "", "makedev(1,2)");

umask 0;

eval { mknod ("/tmp/special", "char", 1, 2, 0600) };
die $@ if $@;

my (@stat) = stat "/tmp/special";
ok(($stat[2] & &S_IFCHR) &&
   ($stat[6] == Sys::Mknod::make_dev(1,2)) &&
   (($stat[2] & 07777) == 0600),
   "make character special device");
unlink "/tmp/special" or die $!;

eval { mknod ("/tmp/special", "block", 1, 2, 0611) };
die $@ if $@;

@stat = stat "/tmp/special";
ok(($stat[2] & &S_IFBLK) &&
   ($stat[6] == Sys::Mknod::make_dev(1,2)) &&
   (($stat[2] & 07777) == 0611),
   "make block special device");
unlink "/tmp/special" or die $!;

eval { mkfifo ("/tmp/fifo") };
@stat = stat "/tmp/fifo";
ok(($stat[2] & &S_IFIFO) &&
   (($stat[2] & 07777) == 0666),
   "make named pipe (fifo)");
unlink "/tmp/fifo" or die $!;

1;
